@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,9 +20,14 @@
 #ifndef PIMDATAEXPORTERCONFIGUREDIALOG_H
 #define PIMDATAEXPORTERCONFIGUREDIALOG_H
 
-#include <QDialog>
+#include <KPageDialog>
+#ifdef WITH_KUSERFEEDBACK
+namespace KUserFeedback {
+class FeedbackConfigWidget;
+}
+#endif
 class PimDataExporterConfigureWidget;
-class PimDataExporterConfigureDialog : public QDialog
+class PimDataExporterConfigureDialog : public KPageDialog
 {
     Q_OBJECT
 public:
@@ -31,8 +36,13 @@ public:
 
 private:
     void slotAccepted();
+    void readConfig();
+    void writeConfig();
 
     PimDataExporterConfigureWidget *mConfigureWidget = nullptr;
+#ifdef WITH_KUSERFEEDBACK
+    KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
+#endif
 };
 
 #endif // PIMDATAEXPORTERCONFIGUREDIALOG_H
